/*

  Calcul de la probabilite d'etre absorbe a gauche
  dans la marche aleatoire symetrique sur {0,...,N}
  (en fonction du point de depart)

*/


#include "markov.hpp"
#include <iostream>


const int n = 20; // Taille de l'espace d'etat
const int nb_simus = 1000; // Nombre de simulations dans la methode de Monte Carlo

int main(void)
{
  markov<n+1> X;
  // On remplit la matrice de transition
  for (int i=1; i<n; i++)
	{
	  X.modif_coeff(i, i+1, 0.5);
	  X.modif_coeff(i, i-1, 0.5);
	}

  std::cout << "#Probabilite d'etre absorbe en 0 partant de X0 (X0=0,...,20)\n";
  
  std::cout << 0 << " " << 1 << std::endl;
  for (int i=1; i<n; i++)// On parcours tous les points de depart possibles
	{
	  double moy = 0;
	  for (int simu=0; simu<nb_simus; simu++)// Le nombre de simulations independantes est nb_simus
		{
		  // On part de i
		  X = i;
		  int t = 0;
		  
		  // On itere la chaine jusqu'a toucher 0 ou n.
		  while (X.pos() != 0 && X.pos() != n)
			{
			  t++;
			  X++;
			}

		  // Si on a touche 0, on ajoute 1 dans le calcul Monte Carlo
		  if (X.pos() == 0)
			moy += 1./nb_simus;
		}
	  std::cout << i << " " << moy << std::endl;
	}
  std::cout << n << " " << 0 << std::endl;
  

  
  return 0;
}
